==> apache-VCL-2.4.2.tar.bz2: apache-VCL-2.4.2/web/js/nls/ja_JP/messages.js <==
/*
* Licensed to the Apache Software Foundation (ASF) under one or more
* contributor license agreements.  See the NOTICE file distributed with
* this work for additional information regarding copyright ownership.
* The ASF licenses this file to You under the Apache License, Version 2.0
* (the "License"); you may not use this file except in compliance with
* the License.  You may obtain a copy of the License at
*
*     http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

nlsmessages = {
'Times cannot be suggested for cluster reservations': 'タイムズは、クラスタの予約のために提案することはできません',
'Cancel': 'キャンセル',
'Okay': '良い',
'Modify Reservation': '予約を変更する',
'Please select a valid environment.': '有効な環境を選択してください。',
'View Available Times': '利用可能時間を表示',
'days': '日',
'hours': '時間',
'hour': '時間',
'Loading...': '負荷',
'The end time must be later than the start time.': '終了時間は開始時間より後のでなければなりません',
'The reservation you selected<br>to edit has expired.<br><br>': '編集する選択した予約は有効期限が切れています',
'The reservation you selected<br>to reboot has expired.<br><br>': '再起動を選択した予約は有効期限が切れています',
'The reservation you selected<br>to reinstall has expired.<br><br>': '再インストールするを選択予約の期限が切れています',
'An invalid version was submitted.': '無効なバージョンが提出されました',
' Ready to connect in ': 'に接続する準備ができました',
' second': '2番目の',
' seconds': '秒',
'match': '一致',
'no match': '不一致',
'Remove': '削除する',
'Skip': 'スキップ',
'Use': '使用',
'Name:': '名',
'Owner:': '所有者',
'specified in comments': 'コメントで指定された',
'Monthly': '毎月',
'First Date:': '最初の日',
'Last Date:': '最後の日',
'Repeat on:': 'を繰り返す',
' of each month': '各月の',
'During these times:': 'これらの時間帯',
'List of Dates/Times': '日付と時刻のリスト',
'Weekly': '毎週',
'Repeating on these days:': 'これらの日に繰り返し',
'User Submitted Comments;': 'ユーザが投稿したコメント',
'Total online: ': '合計オンライン',
'These times overlap with an existing time slot': 'これらの時間は、既存のタイムスロットと重なる',
'The date must be today or later': '日付が今日以降である必要があります',
'The date and times overlap with an existing time slot': '日付と時刻は、既存のタイムスロットと重なる',
'Please fix invalid values before submitting.': '送信する前に、無効な値を修正してください。',
'Please fill in First Date of Usage': '使用の最初の日付を記入してください',
'Please fill in Last Date of Usage': '使用の最終日を記入してください',
'The First Date of Usage must be today or later': '使用の最初の日付は、今日以降である必要があります',
'The Last Date of Usage must be the same or later than the First Date of Usage': '使用の最終日は、後の使用の最初の日付と同じかでなければなりません',
'The Last Date of Usage must be today or later': '使用の最終日が今日以降である必要があります',
'At least one day must be checked when using "Repeating Weekly"': '繰り返しウィークリーを使用する場合は、少なくとも一日をチェックする必要があります',
'At least one start/end combination must be entered when using "Repeating Weekly"': '繰り返しウィークリーを使用する場合は、少なくとも一つの開始/終了の組み合わせを入力する必要があります',
'When submitting "(group not listed)" as the user group, information must be included in the comments about what group needs to be created.': 'ユーザグループとして（記載されていないグループ）提出する際に、情報がどのようなグループを作成する必要があるについてのコメントに含まれる必要があります。',
'At least one start/end combination must be entered when using "Repeating Monthly"': 'At least one start/end combination must be entered when using Repeating Monthly',
'At least one date/start/end combination must be entered when using "List of Dates/Times"': '日付/時刻のリストを使用する場合は、少なくとも一つの日付/開始/終了の組み合わせを入力する必要があります',
'Sunday': '日曜日',
'Monday': '月曜日',
'Tuesday': '火曜日',
'Wednesday': '水曜日',
'Thursday': '木曜日',
'Friday': '金曜日',
'Saturday': '土曜日',
'This must be a valid time that is greater than the start time': 'これは、開始時刻よりも大きい有効な時間でなければなりません'
}

==> apache-VCL-2.5.tar.bz2: apache-VCL-2.5/web/js/nls/ja_JP/messages.js <==
/*
* Licensed to the Apache Software Foundation (ASF) under one or more
* contributor license agreements.  See the NOTICE file distributed with
* this work for additional information regarding copyright ownership.
* The ASF licenses this file to You under the Apache License, Version 2.0
* (the "License"); you may not use this file except in compliance with
* the License.  You may obtain a copy of the License at
*
*     http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

nlsmessages = {
'Times cannot be suggested for cluster reservations': 'タイムズは、クラスタの予約のために提案することはできません',
'Cancel': 'キャンセル',
'Okay': '良い',
'Modify Reservation': '予約を変更する',
'Please select a valid environment.': '有効な環境を選択してください。',
'View Available Times': '利用可能時間を表示',
'days': '日',
'hours': '時間',
'hour': '時間',
'Loading...': '負荷',
'The end time must be later than the start time.': '終了時間は開始時間より後のでなければなりません',
'The reservation you selected<br>to edit has expired.<br><br>': '編集する選択した予約は有効期限が切れています',
'The reservation you selected<br>to reboot has expired.<br><br>': '再起動を選択した予約は有効期限が切れています',
'The reservation you selected<br>to reinstall has expired.<br><br>': '再インストールするを選択予約の期限が切れています',
'An invalid version was submitted.': '無効なバージョンが提出されました',
' Ready to connect in ': 'に接続する準備ができました',
' second': '2番目の',
' seconds': '秒',
'match': '一致',
'no match': '不一致',
'Remove': '削除する',
'Skip': 'スキップ',
'Use': '使用',
'Name:': '名',
'Owner:': '所有者',
'specified in comments': 'コメントで指定された',
'Monthly': '毎月',
'First Date:': '最初の日',
'Last Date:': '最後の日',
'Repeat on:': 'を繰り返す',
' of each month': '各月の',
'During these times:': 'これらの時間帯',
'List of Dates/Times': '日付と時刻のリスト',
'Weekly': '毎週',
'Repeating on these days:': 'これらの日に繰り返し',
'User Submitted Comments;': 'ユーザが投稿したコメント',
'Total online: ': '合計オンライン',
'These times overlap with an existing time slot': 'これらの時間は、既存のタイムスロットと重なる',
'The date must be today or later': '日付が今日以降である必要があります',
'The date and times overlap with an existing time slot': '日付と時刻は、既存のタイムスロットと重なる',
'Please fix invalid values before submitting.': '送信する前に、無効な値を修正してください。',
'Please fill in First Date of Usage': '使用の最初の日付を記入してください',
'Please fill in Last Date of Usage': '使用の最終日を記入してください',
'The First Date of Usage must be today or later': '使用の最初の日付は、今日以降である必要があります',
'The Last Date of Usage must be the same or later than the First Date of Usage': '使用の最終日は、後の使用の最初の日付と同じかでなければなりません',
'The Last Date of Usage must be today or later': '使用の最終日が今日以降である必要があります',
'At least one day must be checked when using "Repeating Weekly"': '繰り返しウィークリーを使用する場合は、少なくとも一日をチェックする必要があります',
'At least one start/end combination must be entered when using "Repeating Weekly"': '繰り返しウィークリーを使用する場合は、少なくとも一つの開始/終了の組み合わせを入力する必要があります',
'When submitting "(group not listed)" as the user group, information must be included in the comments about what group needs to be created.': 'ユーザグループとして（記載されていないグループ）提出する際に、情報がどのようなグループを作成する必要があるについてのコメントに含まれる必要があります。',
'At least one start/end combination must be entered when using "Repeating Monthly"': 'At least one start/end combination must be entered when using Repeating Monthly',
'At least one date/start/end combination must be entered when using "List of Dates/Times"': '日付/時刻のリストを使用する場合は、少なくとも一つの日付/開始/終了の組み合わせを入力する必要があります',
'Sunday': '日曜日',
'Monday': '月曜日',
'Tuesday': '火曜日',
'Wednesday': '水曜日',
'Thursday': '木曜日',
'Friday': '金曜日',
'Saturday': '土曜日',
'This must be a valid time that is greater than the start time': 'これは、開始時刻よりも大きい有効な時間でなければなりません',
'unset':''
}
